summaryrefslogtreecommitdiff
path: root/EdkUnixPkg/Dxe/UnixThunk/Bus/SimpleFileSystem/UnixSimpleFileSystem.c
diff options
context:
space:
mode:
Diffstat (limited to 'EdkUnixPkg/Dxe/UnixThunk/Bus/SimpleFileSystem/UnixSimpleFileSystem.c')
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Bus/SimpleFileSystem/UnixSimpleFileSystem.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Bus/SimpleFileSystem/UnixSimpleFileSystem.c b/EdkUnixPkg/Dxe/UnixThunk/Bus/SimpleFileSystem/UnixSimpleFileSystem.c
index a1b5b32010..2a745cbdd2 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Bus/SimpleFileSystem/UnixSimpleFileSystem.c
+++ b/EdkUnixPkg/Dxe/UnixThunk/Bus/SimpleFileSystem/UnixSimpleFileSystem.c
@@ -15,8 +15,8 @@ Module Name:
Abstract:
- Produce Simple File System abstractions for directories on your PC using Win32 APIs.
- The configuration of what devices to mount or emulate comes from NT
+ Produce Simple File System abstractions for directories on your PC using Posix APIs.
+ The configuration of what devices to mount or emulate comes from UNIX
environment variables. The variables must be visible to the Microsoft*
Developer Studio for them to work.
@@ -1398,7 +1398,7 @@ Returns:
return EFI_SUCCESS;
//
// bugbug: need to access windows error reporting
//
}
@@ -2100,7 +2100,7 @@ Returns:
return PrivateFile->UnixThunk->FSync (PrivateFile->fd) == 0 ? EFI_SUCCESS : EFI_DEVICE_ERROR;
//
// bugbug: - Use Windows error reporting.
//
}
@@ -1398,7 +1398,7 @@ Returns:
return EFI_SUCCESS;
//
- // bugbug: need to access windows error reporting
+ // bugbug: need to access unix error reporting
//
}
@@ -2100,7 +2100,7 @@ Returns:
return PrivateFile->UnixThunk->FSync (PrivateFile->fd) == 0 ? EFI_SUCCESS : EFI_DEVICE_ERROR;
//
- // bugbug: - Use Windows error reporting.
+ // bugbug: - Use Unix error reporting.
//
}